@@ -1,4 +1,5 @@
 from .preprocessing import *
-from .NeuralNetwork import Sequential
+from .FFNN import Sequential
+from .LinearRegression import LinearRegression
 from .functions import *
 from .metrics import *
\ No newline at end of file
